@@ -95,7 +95,7 @@ void R_init_lpSolveAPI(DllInfo *info)
     {"RlpSolve_is_int", (DL_FUNC) RlpSolve_is_int, 2},
     {"RlpSolve_set_lowbo", (DL_FUNC) RlpSolve_set_lowbo, 3},
     {"RlpSolve_get_lowbo", (DL_FUNC) RlpSolve_get_lowbo, 2},
-    {"RlpSolve_setlp_name", (DL_FUNC) RlpSolve_set_lp_name, 2},
+    {"RlpSolve_set_lp_name", (DL_FUNC) RlpSolve_set_lp_name, 2},
     {"RlpSolve_get_lp_name", (DL_FUNC) RlpSolve_get_lp_name, 1},
     {"RlpSolve_set_mat", (DL_FUNC) RlpSolve_set_mat, 4},
     {"RlpSolve_get_mat", (DL_FUNC) RlpSolve_get_mat, 3},
@@ -172,6 +172,8 @@ void R_init_lpSolveAPI(DllInfo *info)
     {"RlpSolve_get_presolve", (DL_FUNC) RlpSolve_get_presolve, 1},
     {"RlpSolve_get_presolveloops", (DL_FUNC) RlpSolve_get_presolveloops, 1},
     {"RlpSolve_is_presolve", (DL_FUNC) RlpSolve_is_presolve, 2},
+    {"RlpSolve_set_scalelimit", (DL_FUNC) RlpSolve_set_scalelimit, 2},
+    {"RlpSolve_get_scalelimit", (DL_FUNC) RlpSolve_get_scalelimit, 1},
     {"RlpSolve_set_scaling", (DL_FUNC) RlpSolve_set_scaling, 2},
     {"RlpSolve_get_scaling", (DL_FUNC) RlpSolve_get_scaling, 1},
     {"RlpSolve_is_integerscaling", (DL_FUNC) RlpSolve_is_integerscaling, 1},
